==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/UserProfileUserSettingsRSessionAppSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property customImages A list of custom SageMaker images that are configured to run as a KernelGateway app. see Custom Image below.
 * @property defaultResourceSpec The default instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance. see Default Resource Spec below.
 */
public data class UserProfileUserSettingsRSessionAppSettings(
    public val customImages: List<UserProfileUserSettingsRSessionAppSettingsCustomImage>? = null,
    public val defaultResourceSpec: UserProfileUserSettingsRSessionAppSettingsDefaultResourceSpec? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.UserProfileUserSettingsRSessionAppSettings):
            UserProfileUserSettingsRSessionAppSettings = UserProfileUserSettingsRSessionAppSettings(
            customImages = javaType.customImages().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.sagemaker.kotlin.outputs.UserProfileUserSettingsRSessionAppSettingsCustomImage.Companion.toKotlin(args0)
                })
            }),
            defaultResourceSpec = javaType.defaultResourceSpec().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.sagemaker.kotlin.outputs.UserProfileUserSettingsRSessionAppSettingsDefaultResourceSpec.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/UserProfileUserSettingsRSessionAppSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property customImages A list of custom SageMaker images that are configured to run as a KernelGateway app. see Custom Image below.
 * @property defaultResourceSpec The default instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance. see Default Resource Spec below.
 */
public data class UserProfileUserSettingsRSessionAppSettings(
    public val customImages: List<UserProfileUserSettingsRSessionAppSettingsCustomImage>? = null,
    public val defaultResourceSpec: UserProfileUserSettingsRSessionAppSettingsDefaultResourceSpec? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.UserProfileUserSettingsRSessionAppSettings): UserProfileUserSettingsRSessionAppSettings = UserProfileUserSettingsRSessionAppSettings(
            customImages = javaType.customImages().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.sagemaker.kotlin.outputs.UserProfileUserSettingsRSessionAppSettingsCustomImage.Companion.toKotlin(args0)
                })
            }),
            defaultResourceSpec = javaType.defaultResourceSpec().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.sagemaker.kotlin.outputs.UserProfileUserSettingsRSessionAppSettingsDefaultResourceSpec.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
